STANNIX Solutions for the Real World


Manual: git-pull

GIT-PULL(1)					 Git Manual					 GIT-PULL(1)

NAME
       git-pull - Fetch from and integrate with another repository or a local branch

SYNOPSIS
       git pull [] [ [...]]

DESCRIPTION
       Integrate changes from a remote repository into the current branch.

       First, git pull runs git fetch with the same arguments (excluding merge options) to fetch remote
       branch(es). Then it decides which remote branch to integrate: if you run git pull with no arguments
       this defaults to the upstream for the current branch. Then it integrates that branch into the current
       branch.

       There are 4 main options for integrating the remote branch:

	1. git pull --ff-only will only do "fast-forward" updates: it fails if your local branch has
	   diverged from the remote branch. This is the default.

	2. git pull --rebase runs git rebase

	3. git pull --no-rebase runs git merge.

	4. git pull --squash runs git merge --squash

       You can also set the configuration options pull.rebase, pull.squash, or pull.ff with your preferred
       behaviour.

       If there’s a merge conflict during the merge or rebase that you don’t want to handle, you can safely
       abort it with git merge --abort or git rebase --abort.

OPTIONS
       
	   The "remote" repository to pull from. This can be either a URL (see the section GIT URLS below)
	   or the name of a remote (see the section REMOTES below).

	   Defaults to the configured upstream for the current branch, or origin. See UPSTREAM BRANCHES
	   below for more on how to configure upstreams.

       
	   Which branch or other reference(s) to fetch and integrate into the current branch, for example
	   main in git pull origin main. Defaults to the configured upstream for the current branch.

	   This can be a branch, tag, or other collection of reference(s). See  below under
	   "Options related to fetching" for the full syntax, and DEFAULT BEHAVIOUR below for how git pull
	   uses this argument to determine which remote branch to integrate.

       -q, --quiet
	   This is passed to both underlying git-fetch to squelch reporting of during transfer, and
	   underlying git-merge to squelch output during merging.

       -v, --verbose
	   Pass --verbose to git-fetch and git-merge.

       --recurse-submodules[=(yes|on-demand|no)], --no-recurse-submodules
	   This option controls if new commits of populated submodules should be fetched, and if the working
	   trees of active submodules should be updated, too (see git-fetch(1), git-config(1) and
	   gitmodules(5)).

	   If the checkout is done via rebase, local submodule commits are rebased as well.

	   If the update is done via merge, the submodule conflicts are resolved and checked out.

   Options related to merging
       --commit, --no-commit
	   Perform the merge and commit the result. This option can be used to override --no-commit. Only
	   useful when merging.

	   With --no-commit perform the merge and stop just before creating a merge commit, to give the user
	   a chance to inspect and further tweak the merge result before committing.

	   Note that fast-forward updates do not create a merge commit and therefore there is no way to stop
	   those merges with --no-commit. Thus, if you want to ensure your branch is not changed or updated
	   by the merge command, use --no-ff with --no-commit.

       --edit, -e, --no-edit
	   Invoke an editor before committing successful mechanical merge to further edit the auto-generated
	   merge message, so that the user can explain and justify the merge. The --no-edit option can be
	   used to accept the auto-generated message (this is generally discouraged).

	   Older scripts may depend on the historical behaviour of not allowing the user to edit the merge
	   log message. They will see an editor opened when they run git merge. To make it easier to adjust
	   such scripts to the updated behaviour, the environment variable GIT_MERGE_AUTOEDIT can be set to
	   no at the beginning of them.

       --cleanup=
	   This option determines how the merge message will be cleaned up before committing. See git-
	   commit(1) for more details. In addition, if the  is given a value of scissors, scissors
	   will be appended to MERGE_MSG before being passed on to the commit machinery in the case of a
	   merge conflict.

       --ff-only
	   Only update to the new history if there is no divergent local history. This is the default when
	   no method for reconciling divergent histories is provided (via the --rebase flags).

       --ff, --no-ff
	   When merging rather than rebasing, specifies how a merge is handled when the merged-in history is
	   already a descendant of the current history. If merging is requested, --ff is the default unless
	   merging an annotated (and possibly signed) tag that is not stored in its natural place in the
	   refs/tags/ hierarchy, in which case --no-ff is assumed.

	   With --ff, when possible resolve the merge as a fast-forward (only update the branch pointer to
	   match the merged branch; do not create a merge commit). When not possible (when the merged-in
	   history is not a descendant of the current history), create a merge commit.

	   With --no-ff, create a merge commit in all cases, even when the merge could instead be resolved
	   as a fast-forward.

       -S[], --gpg-sign[=], --no-gpg-sign
	   GPG-sign the resulting merge commit. The  argument is optional and defaults to the
	   committer identity; if specified, it must be stuck to the option without a space.  --no-gpg-sign
	   is useful to countermand both commit.gpgSign configuration variable, and earlier --gpg-sign.

       --log[=], --no-log
	   In addition to branch names, populate the log message with one-line descriptions from at most 
	   actual commits that are being merged. See also git-fmt-merge-msg(1). Only useful when merging.

	   With --no-log do not list one-line descriptions from the actual commits being merged.

       --signoff, --no-signoff
	   Add a Signed-off-by trailer by the committer at the end of the commit log message. The meaning of
	   a signoff depends on the project to which you’re committing. For example, it may certify that the
	   committer has the rights to submit the work under the project’s license or agrees to some
	   contributor representation, such as a Developer Certificate of Origin. (See
	   https://developercertificate.org for the one used by the Linux kernel and Git projects.) Consult
	   the documentation or leadership of the project to which you’re contributing to understand how the
	   signoffs are used in that project.

	   The --no-signoff option can be used to countermand an earlier --signoff option on the command
	   line.

	   Git does not (and will not) have a configuration variable to enable the --signoff command line
	   option by default; see the commit.signoff entry in gitfaq(7) for more details.

       --stat, -n, --no-stat
	   Show a diffstat at the end of the merge. The diffstat is also controlled by the configuration
	   option merge.stat.

	   With -n or --no-stat do not show a diffstat at the end of the merge.

       --compact-summary
	   Show a compact-summary at the end of the merge.

       --squash, --no-squash
	   Produce the working tree and index state as if a real merge happened (except for the merge
	   information), but do not actually make a commit, move the HEAD, or record $GIT_DIR/MERGE_HEAD (to
	   cause the next git commit command to create a merge commit). This allows you to create a single
	   commit on top of the current branch whose effect is the same as merging another branch (or more
	   in case of an octopus).

	   With --no-squash perform the merge and commit the result. This option can be used to override
	   --squash.

	   With --squash, --commit is not allowed, and will fail.

	   Only useful when merging.

       --verify, --no-verify
	   By default, the pre-merge and commit-msg hooks are run. When --no-verify is given, these are
	   bypassed. See also githooks(5). Only useful when merging.

       -s , --strategy=
	   Use the given merge strategy; can be supplied more than once to specify them in the order they
	   should be tried. If there is no -s option, a built-in list of strategies is used instead (ort
	   when merging a single head, octopus otherwise).

       -X